This software is used to calculate the thermodynamic potentials of materials and ideal gases. The calculations are based on energetic and vibrational data from theory (for example, density functional theory) or experiment. By calculating the thermodynamic potentials of both products and reactants, this software can also produce a thermodynamic model for the stability of a material under arbitrary temperatures and pressures. 

## Research outputs

- This model was originally developed for the photovoltaic material CZTS and published in a [2014 publication in *J. Mater. Chem. A*](http://dx.doi.org/10.1039/C4TA00892H).
- It has been more recently applied to the chalcogenide perovskite BaZrS3 and published in a [2023 publication in *Solar RRL*](https://doi.org/10.1002/solr.202201078).

## Experimental data

Experimental data is used to model the pressure and temperature dependance of gases. In particular the NIST-JANAF thermochemical tables are used: Chase, M. W. J. NIST-JANAF Thermochemical Tables, Fourth Edition. J. Phys. Chem. Ref. Data, Monogr. 9, 1-1951 (1998). https://srd.nist.gov/JPCRD/jpcrdM9.pdf.

## Further reading

- Materials Stability and Nature's bike shop: A comics guide to predicting new materials, Anubhav Jain (2014). Link [here](https://hackingmaterials.files.wordpress.com/2014/05/phasediagram_comic2.pdf)
- Phase Diagrams: The Beginning of Wisdom. Rainer Schmid-Fetzer (2014): Link [here](https://files.core.ac.uk/pdf/2612/81879090.pdf).
